@@ -306,6 +306,7 @@ public class CDF2CDFML implements CDFConstants {
             String majority = CDFUtils.getStringMajority(cdf);
             String encoding = CDFUtils.getStringEncoding(cdf);
             String checksum = CDFUtils.getStringChecksum(cdf);
+            long lastUpdated = CDFUtils.getLeapSecondLastUpdated(cdf);
 
             indent++;
             outputIndentation(indent); 
@@ -329,6 +330,9 @@ public class CDF2CDFML implements CDFConstants {
                 !checksum.equalsIgnoreCase("other"))
                 out.print (" checksum=\""+checksum+"\"");
 
+            if (lastUpdated > -1)
+                out.print (" leapsecondlastupdated=\""+lastUpdated+"\"");
+
             out.println ("/>");
 
         } catch (Exception e) {
