@@ -6,6 +6,9 @@
 /*
  * This program is for converting a cdf.dtd or cdf.xsd compliant XML file 
  * to a CDF file. The SAX parser is used for parsing the document.
+ *
+ * Modified: May 20, 2015 (ML) Changed exit status to 0 if ends successfully.
+ *                             1, otherwise.
  */ 
 import java.lang.reflect.*;
 import gsfc.nssdc.cdf.*;
@@ -57,6 +60,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
     private Stack stack;
     private CDFML2CDF aXML2CDF;
     private StringBuffer dataBuffer;
+    private long lastUpdated = -1L;
 
     public static void main(String argv[]) {
 
@@ -125,7 +129,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
         File cdfmlFile = new File (cdfml);
         if (!cdfmlFile.exists()) {
           System.err.println("*** Error: cdfml file:"+cdfmlFile+" does not exist! ***");
-          System.exit(0);
+          System.exit(1);
 	}
 
     }
@@ -162,7 +166,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
             check2 = false;
           } else {
             System.err.println("\nError... CDF: "+file1+" already exists...");
-            System.exit(0);
+            System.exit(1);
           }
         }
         if (check2 && file2 != null) {
@@ -173,7 +177,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
               cdfFile2.delete();
             } else {
               System.err.println("\nError... CDF: "+file2+" already exists...");
-              System.exit(0);
+              System.exit(1);
             }
           }
         }
@@ -214,13 +218,13 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
            } catch (Throwable t2) {
               System.err.println(" ");
               t2.printStackTrace();
-              System.exit(0);
+              System.exit(1);
            }
 /*
         } catch (Throwable t) {
 	    System.err.println(" ");
             t.printStackTrace();
-	    System.exit(0);
+	    System.exit(1);
 */
         }
         StringBuffer fName = new StringBuffer(cdfName);
@@ -228,7 +232,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
           fName.append(".cdf");
         System.err.println("Completed!  CDF file: "+fName.toString()+" is created.");
 
-        System.exit(1);
+        System.exit(0);
 
     }     
 
@@ -259,7 +263,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 	      break;
 	    } catch (CDFException e) {
 	      System.err.println("\n ***** CDFException 1..: "+e);
-	      System.exit(0);
+	      System.exit(1);
 	    }
 	  } 
 	}
@@ -281,7 +285,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
               break;
             } catch (CDFException e) {
               System.err.println("\n ****** CDFException 2..: "+e);
-	      System.exit(0);
+	      System.exit(1);
             }
           }
         }
@@ -455,7 +459,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 	    elementDelimiter = null;
           } catch (SAXException e) {
             System.err.println("\n SAXException....: "+e);
-            System.exit(0);
+            System.exit(1);
           }
 	} else if (s.equalsIgnoreCase("entry")) {
           entryBlock = false;
@@ -464,7 +468,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 		elementDelimiter = null;
           } catch (SAXException e) {
             System.err.println("\n SAXException....: "+e);
-            System.exit(0);
+            System.exit(1);
           }
         } else if (s.equalsIgnoreCase("element")) {
 	  elementBlock = false;
@@ -475,7 +479,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 	    elementDelimiter = null;
           } catch (SAXException e) {
             System.err.println("\n SAXException....: "+e);
-            System.exit(0);
+            System.exit(1);
           }
 	} else if (s.equalsIgnoreCase("variable")) {
 	  dimSizes = null;
@@ -517,7 +521,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 	       }
         } catch (CDFException e) {
           System.err.println("\n CDFException 3..: "+e);
-	  System.exit(0);
+	  System.exit(1);
         }
         dataBuffer.setLength(0);
 
@@ -635,6 +639,9 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
               } else if (aName.equalsIgnoreCase("checksum")) {
                 long checksum = CDFUtils.getLongChecksum(attrs.getValue(i));
                 cdf.setChecksum(checksum);
+              } else if (aName.equalsIgnoreCase("leapsecondlastupdated")) {
+                lastUpdated = new Long(attrs.getValue(i)).longValue();
+                cdf.setLeapSecondLastUpdated(lastUpdated);
               } else if (aName.equalsIgnoreCase("CDFCacheSize")) {
                 long cdfCacheSize = new Long(attrs.getValue(i)).longValue();
                 cdf.selectCDFCacheSize(cdfCacheSize);
@@ -790,8 +797,12 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
           }
         } else if (entryDataType == CDF_TIME_TT2000) {
           entryValue = new long[iTokens];
-          for (int i = 0; i < iTokens; i++)
-            ((long[]) entryValue)[i] = CDFTT2000.fromUTCstring(st.nextToken());
+          for (int i = 0; i < iTokens; i++) {
+	    if ((int)lastUpdated == -1 || (int)lastUpdated == 0) 
+              ((long[]) entryValue)[i] = CDFTT2000.fromUTCstring(st.nextToken());
+	    else
+	      ((long[]) entryValue)[i] = CDFTT2000.parseTT2000withBasedLeapDay(st.nextToken(), (int)lastUpdated);
+	  }
         } else
 	  entryValue = null;
 	return entryValue;
@@ -980,7 +991,10 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
                   else /* ISO 8601 format. */
                     padValue = Epoch16.parse4(tmp);
                 } else if (varDataType == CDF_TIME_TT2000) {
-                    padValue = new Long(CDFTT2000.fromUTCstring(tmp));
+		    if ((int)lastUpdated == -1 || (int)lastUpdated == 0)
+                      padValue = new Long(CDFTT2000.fromUTCstring(tmp));
+		    else
+                      padValue = new Long(CDFTT2000.parseTT2000withBasedLeapDay(tmp, (int)lastUpdated));
                 }
               }
           }
@@ -1122,8 +1136,12 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
            }
         } else if (varDataType == CDF_TIME_TT2000) {
            dataValues = new long[iTokens];
-           for (int ij = 0; ij < iTokens; ++ij)
-             ((long[]) dataValues)[ij] = CDFTT2000.fromUTCstring(st.nextToken());
+           for (int ij = 0; ij < iTokens; ++ij) {
+	     if ((int)lastUpdated == -1 || (int)lastUpdated == 0) 
+               ((long[]) dataValues)[ij] = CDFTT2000.fromUTCstring(st.nextToken());
+	     else
+               ((long[]) dataValues)[ij] = CDFTT2000.parseTT2000withBasedLeapDay(st.nextToken(), (int)lastUpdated);
+	   }
         }
 	if (dataValues != null) {
 //	  arrayify(dataValues, dataObject, (int) (items*numElements), phyDims, dimSizes);
@@ -1177,7 +1195,10 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
           else /* ISO 8601 format. */
             dataValue = Epoch16.parse4(tmp);
         } else if (varDataType == CDF_TIME_TT2000) {
-            dataValue = new Long(CDFTT2000.fromUTCstring(tmp));
+	    if ((int)lastUpdated == -1 || (int)lastUpdated == 0)
+              dataValue = new Long(CDFTT2000.fromUTCstring(tmp));
+	    else
+              dataValue = new Long(CDFTT2000.parseTT2000withBasedLeapDay(tmp, (int)lastUpdated));
         }
 	if (dataValue != null) 
 	  var.putSingleData(recNum, dimIndex, dataValue);
@@ -1411,7 +1432,7 @@ public class CDFML2CDF extends DefaultHandler implements CDFConstants {
 	System.err.println("          use Oracle's parser and create /home/mydir/xxxx.cdf where xxxx comes");
 	System.err.println("          from the name attribute at the CDF element in myCDFML.xml."); 
 	System.err.println(" ");
-        System.exit(1);
+        System.exit(0);
         
    }
 
