@@ -1,5 +1,8 @@
-
-//package gsfc.nssdc.cdf;
+/******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
 
 import java.io.*;
 import java.lang.*;
@@ -8,7 +11,6 @@ import java.util.*;
 import gsfc.nssdc.cdf.*;
 import gsfc.nssdc.cdf.util.*;
 
-
 public class GetMyCDFData implements CDFConstants {
 
     /**
@@ -222,21 +224,39 @@ public class GetMyCDFData implements CDFConstants {
                 if (dataType == CDF_CHAR || dataType == CDF_UCHAR) 
                     outWriter.print ("<![CDATA[");
                 if (dataType == CDF_EPOCH) {
-                    Double lEpoch = (Double) _dataArray;
-                    outWriter.print (((!iso8601)?
-                                      Epoch.encode(lEpoch.doubleValue()):
-                                      Epoch.encode4(lEpoch.doubleValue())));
+                    if (!_dataArray.getClass().isArray()) {
+                      Double lEpoch = (Double) _dataArray;
+                      outWriter.print (((!iso8601)?
+                                        Epoch.encode(lEpoch.doubleValue()):
+                                        Epoch.encode4(lEpoch.doubleValue())));
+                    } else {
+                      double lEpoch = ((double[]) _dataArray)[0];
+                      outWriter.print (((!iso8601)?
+                                        Epoch.encode(lEpoch):
+                                        Epoch.encode4(lEpoch)));
+                    }
                 } else if (dataType == CDF_EPOCH16) {
                     double[] lEpoch = (double[]) _dataArray;
                     outWriter.print (((!iso8601)?
                                       Epoch16.encode(lEpoch):
                                       Epoch16.encode4(lEpoch)));
                 } else if (dataType == CDF_TIME_TT2000) {
-                    Long lEpoch = (Long) _dataArray;
-                    outWriter.print (CDFTT2000.toUTCstring(lEpoch.longValue()));
+                    if (!_dataArray.getClass().isArray()) {
+                      Long lEpoch = (Long) _dataArray;
+                      outWriter.print (CDFTT2000.toUTCstring(lEpoch.longValue()));
+                    } else {
+                      long lEpoch = ((long[]) _dataArray)[0];
+                      outWriter.print (CDFTT2000.toUTCstring(lEpoch));
+                    }
                 } 
-                else 
-                    outWriter.print(_dataArray.toString());
+                else { 
+                    if (!_dataArray.getClass().isArray())
+                      outWriter.print(_dataArray.toString());
+                    else {
+                      Object ttt = Array.get(_dataArray,0);
+                      outWriter.print(ttt.toString());
+                    }
+                }
                 if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
                     outWriter.print ("]]>");
                 }
