@@ -27,6 +27,7 @@ public class CDFConvert extends JFrame
 /** The dialog for user interface. */
     JDialog dialog;
 
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 /** The FileChooser for the file selection. */
     JFileChooser fileChooser = new JFileChooser();
 
@@ -432,7 +433,8 @@ public class CDFConvert extends JFrame
         cdf2.setFont(boldFont);
         SKLT.setFont(boldFont);
         sklt.setFont(boldFont);
-	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+//	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+	panelx.add(panel1,BorderLayout.NORTH);
 	
         // Panel 2
 
@@ -746,7 +748,8 @@ public class CDFConvert extends JFrame
         COMP.setFont(boldFont);
         compression.setFont(boldFont);
 
-        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+//        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+        panelx.add(panel2,BorderLayout.CENTER);
 
         // Panel 3 (buttons and text area)
 
@@ -777,9 +780,14 @@ public class CDFConvert extends JFrame
                 }
         };
         scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.SOUTH);
-	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+//        panel3.add(scroller, BorderLayout.SOUTH);
+//	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+	panelx.add(panel3, BorderLayout.SOUTH);
   	info.setVisible(true);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Implement the run method for Runabout interface.
