@@ -27,6 +27,7 @@ public class CDFDump extends JFrame
 
 /** The FileChooser for the file selection. */
     JFileChooser fileChooser = new JFileChooser();
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 
 /** The panel for text fields and selectable buttons which goes to dialog's
     north portion. */
@@ -327,7 +328,8 @@ public class CDFDump extends JFrame
         cdf.setFont(boldFont);
         OUTF.setFont(boldFont);
         outf.setFont(boldFont);
-	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+//	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+	panelx.add(panel1,BorderLayout.NORTH);
 	
         tpanel1.add(DUMP,BorderLayout.WEST);
         tpanel1.add(dumpPanel, BorderLayout.CENTER);
@@ -397,7 +399,8 @@ public class CDFDump extends JFrame
         RECS.setFont(boldFont);
         recs.setFont(boldFont);
 
-        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+//        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+        panelx.add(panel2,BorderLayout.CENTER);
 
         // Panel 3 (buttons and text area)
 
@@ -428,10 +431,15 @@ public class CDFDump extends JFrame
                 }
         };
         scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.SOUTH);
+//        panel3.add(scroller, BorderLayout.SOUTH);
   	info.setVisible(true);
 
-  	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+//  	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+  	panelx.add(panel3, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Implement the run method for Runabout interface.
