@@ -24,6 +24,7 @@ public class CDFLeapSecondsInfo extends JFrame
 /** dialog for user interface. */
     JDialog dialog;
 
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 /** The panel for selectable buttons which goes to dialog's north portion. */
     JPanel panel1 = new JPanel(new GridBagLayout(), true);
 /** The panel for run/help/quit buttons. */
@@ -179,7 +180,8 @@ public class CDFLeapSecondsInfo extends JFrame
         dpc.setToolTipText("Display the contents of the leap seconds table");
         abc.addItemListener(this);
         abc.setToolTipText("Display the current version");
-	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+//	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+	panelx.add(panel1,BorderLayout.NORTH);
 	
 
         // Panel 2
@@ -189,7 +191,8 @@ public class CDFLeapSecondsInfo extends JFrame
         panel21.add(quitb);
         panel2.add(panel21, BorderLayout.NORTH);
         panel2.add(Box.createRigidArea(vpad20),BorderLayout.SOUTH);
-	dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+//	dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+	panelx.add(panel2,BorderLayout.CENTER);
 
         // Listen for events on buttons
         entrb.addActionListener(this);
@@ -213,9 +216,14 @@ public class CDFLeapSecondsInfo extends JFrame
         };
 
 	scroller.getViewport().add(info);
-        panel3.add(scroller, BorderLayout.CENTER);
+//        panel3.add(scroller, BorderLayout.CENTER);
         info.setVisible(true);
-        dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+//        dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+        panelx.add(panel3, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
 
     }
 
