@@ -1,4 +1,4 @@
-//$Id: CDFSpecPanel.java,v 1.2 2014/05/14 17:38:06 liu Exp $
+//$Id: CDFSpecPanel.java,v 1.1.1.1 2017/01/04 20:58:10 liu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -32,7 +32,7 @@ public class CDFSpecPanel extends JLabeledPanel implements CDFConstants
 
     private JLabeledTF
 	version, format, encoding, majority, numzVars, numAttrs, maxRecN, 
-        compression, checksum;
+        compression, checksum, lastUpdated;
     private Font numAttrCurrFont;
 
     static final long serialVersionUID = 1L;
@@ -86,15 +86,21 @@ public class CDFSpecPanel extends JLabeledPanel implements CDFConstants
         checksum.textField.setOpaque(false);
         checksum.textField.setBorder(new EmptyBorder(0,0,0,0));
         
-	add(version); add(Box.createRigidArea(new Dimension(4,1)));
-	add(format); add(Box.createRigidArea(new Dimension(4,1)));
-	add(encoding); add(Box.createRigidArea(new Dimension(4,1)));
-	add(majority); add(Box.createRigidArea(new Dimension(4,1)));
-        add(numzVars); add(Box.createRigidArea(new Dimension(4,1)));
-        add(numAttrs); add(Box.createRigidArea(new Dimension(4,1)));
-        add(maxRecN); add(Box.createRigidArea(new Dimension(4,1)));
-        add(compression); add(Box.createRigidArea(new Dimension(4,1)));
-	add(checksum); 
+        lastUpdated  = new JLabeledTF("LeapTableUpdated", 8);
+        lastUpdated.textField.setEditable(false);
+        lastUpdated.textField.setOpaque(false);
+        lastUpdated.textField.setBorder(new EmptyBorder(0,0,0,0));
+        
+	add(version); add(Box.createRigidArea(new Dimension(3,1)));
+	add(format); add(Box.createRigidArea(new Dimension(3,1)));
+	add(encoding); add(Box.createRigidArea(new Dimension(3,1)));
+	add(majority); add(Box.createRigidArea(new Dimension(3,1)));
+        add(numzVars); add(Box.createRigidArea(new Dimension(3,1)));
+        add(numAttrs); add(Box.createRigidArea(new Dimension(3,1)));
+        add(maxRecN); add(Box.createRigidArea(new Dimension(3,1)));
+        add(compression); add(Box.createRigidArea(new Dimension(3,1)));
+	add(checksum); add(Box.createRigidArea(new Dimension(3,1))); 
+	add(lastUpdated); 
 
     }
 	
@@ -114,6 +120,7 @@ public class CDFSpecPanel extends JLabeledPanel implements CDFConstants
         maxRecN.set("");
         compression.set("");
 	checksum.set("");
+	lastUpdated.set("");
 
     }
 
@@ -126,7 +133,8 @@ public class CDFSpecPanel extends JLabeledPanel implements CDFConstants
     public void set(CDF cdf) {
 
 	try {
-	  version.set(cdf.getVersion());
+	  String cdfVersion = cdf.getVersion();
+	  version.set(cdfVersion);
 	  format.set(CDFUtils.getStringFormat(cdf));
 	  encoding.set(CDFUtils.getStringEncoding(cdf));
           majority.set(CDFUtils.getStringMajority(cdf));
@@ -144,6 +152,11 @@ public class CDFSpecPanel extends JLabeledPanel implements CDFConstants
           maxRecN.set("" + (maxRec+1));
           compression.set(cdf.getCompression());
 	  checksum.set(CDFUtils.getStringChecksum(cdf));
+	  long lastTT2000 = cdf.getLeapSecondLastUpdated();
+	  if (cdfVersion.compareTo("3.6.0") < 0 || lastTT2000 < 0)
+	    lastUpdated.set("Not Set");
+	  else
+	    lastUpdated.set(""+lastTT2000);
 	} catch (CDFException e) {
 	  System.err.println("Error: " + e.toString()); 
 	}
