@@ -37,7 +37,6 @@ public class CDFToolUtils implements CDFConstants {
         while (st.hasMoreTokens()) {
 	  vec.addElement(st.nextToken());
         }
-
 	int filterElementsNum = vec.size();
         if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
 	    // move in the data as is
@@ -56,31 +55,71 @@ public class CDFToolUtils implements CDFConstants {
 	} else if (dataType == CDF_UINT1 || dataType == CDF_INT2) {
           if (filterElementsNum == 1) {
 	    short[] aShort = {Short.parseShort(data)};
+	    if (dataType == CDF_UINT1) {
+	      if (aShort[0] < 0 || aShort[0] > 255) {
+		aShort = null;
+		throw new NumberFormatException(data);
+	      }
+	    }		
 	    return aShort;
           } else {
             short[] aShort = new short[filterElementsNum];
-            for (int i = 0; i < filterElementsNum; i++) 
+            for (int i = 0; i < filterElementsNum; i++) {
               aShort[i] = Short.parseShort(((String)(vec.elementAt(i))).trim());
+              if (dataType == CDF_UINT1) {
+                if (aShort[i] < 0 || aShort[i] > 255) {
+		  aShort = null;
+		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
+		}
+              }
+	    }
 	    return aShort;
           }
 	} else if (dataType == CDF_UINT2 || dataType == CDF_INT4) {
 	  if (filterElementsNum == 1) {
 	    int[] aInteger = {Integer.parseInt(data)};
+            if (dataType == CDF_UINT2) {
+              if (aInteger[0] < 0 || aInteger[0] > 65535) {
+		aInteger = null;
+		throw new NumberFormatException(data);
+	      }
+            }
 	    return aInteger;
 	  } else {
 	    int[] aInteger = new int[filterElementsNum];
-	    for (int i = 0; i < filterElementsNum; i++) 
+	    for (int i = 0; i < filterElementsNum; i++) {
 	      aInteger[i] = Integer.parseInt(((String)(vec.elementAt(i))).trim());
+              if (dataType == CDF_UINT2) {
+                if (aInteger[i] < 0 || aInteger[i] > 65535) {
+		  aInteger = null;
+		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
+		}
+              }
+	    }
 	    return aInteger;
 	  }
 	} else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
           if (filterElementsNum == 1) {
 	    long[] aLong = {Long.parseLong(data)};
+            if (dataType == CDF_UINT4) {
+              if (aLong[0] < 0 || aLong[0] > 4294967285L) {
+		aLong = null;
+		throw new NumberFormatException(data);
+	      }
+            }
+
 	    return aLong;
           } else {
             long[] aLong = new long[filterElementsNum];
-            for (int i = 0; i < filterElementsNum; i++) 
+            for (int i = 0; i < filterElementsNum; i++) {
               aLong[i] = Long.parseLong(((String)(vec.elementAt(i))).trim());
+              if (dataType == CDF_UINT4) {
+                if (aLong[i] < 0 || aLong[i] > 4294967285L) {
+		  aLong = null;
+		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
+		}
+              }
+	    }
 	    return aLong;
           }
 	} else if (dataType == CDF_FLOAT || dataType == CDF_REAL4) {
@@ -181,6 +220,29 @@ public class CDFToolUtils implements CDFConstants {
 	return null;
     }
 
+/**
+ *  This method parses a string and returns an object based upon the data type
+ */
+
+    public static Object parseContent (String data, long dataType, long numElems) throws CDFException, NumberFormatException {
+
+        data = data.trim();
+        if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
+            // move in the data as is
+           String tmpString;
+           if (data.substring(0,1).equals("\""))
+	     if (data.substring(data.length()-1).equals("\""))
+               tmpString = new StringBuffer(data).substring(1,data.length()-1);
+	     else
+               tmpString = data;
+           else
+             tmpString =  data;
+           if (tmpString.length() > numElems) throw new CDFException(BAD_NUM_ELEMS);
+           else return tmpString;
+        } else 
+	   return CDFToolUtils.parseContent (data, dataType);
+    }
+
 /**
  *  This method parses a string and returns an object based upon the data type
  */
@@ -191,19 +253,44 @@ public class CDFToolUtils implements CDFConstants {
 
         if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
             // move in the data as is
-            String aStr = data;
-            return aStr;
+	   String tmpString;
+	   if (data.substring(0,1).equals("\"")) 
+	     if (data.substring(data.length()-1).equals("\""))
+	       tmpString = new StringBuffer(data).substring(1,data.length()-1);
+	     else
+	       tmpString = data;
+	   else
+	     tmpString =  data;
+	   return tmpString;
         } else if (dataType == CDF_BYTE || dataType == CDF_INT1) {
             Byte aByte = new Byte(data);
             return aByte;
         } else if (dataType == CDF_UINT1 || dataType == CDF_INT2) {
             Short aShort = new Short(data);
+            if (dataType == CDF_UINT1) {
+              if (aShort.shortValue() < 0 || aShort.shortValue() > 255) {
+		aShort = null;
+		throw new NumberFormatException(data);
+	      }
+            }           
             return aShort;
         } else if (dataType == CDF_UINT2 || dataType == CDF_INT4) {
             Integer aInteger = new Integer(data);
+            if (dataType == CDF_UINT2) {
+              if (aInteger.shortValue() < 0 || aInteger.intValue() > 65535) {
+		aInteger = null;
+		throw new NumberFormatException(data);
+	      }
+            }           
             return aInteger;
         } else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
             Long aLong = new Long(data);
+            if (dataType == CDF_UINT4) {
+              if (aLong.shortValue() < 0 || aLong.longValue() > 4294967285L) {
+		aLong = null;
+		throw new NumberFormatException(data);
+	      }
+            }           
             return aLong;
         } else if (dataType == CDF_FLOAT || dataType == CDF_REAL4) {
             Float aFloat = new Float(data);
