@@ -1,4 +1,4 @@
-// $Id: EditVariableDialog.java,v 1.2 2014/05/14 17:38:06 liu Exp $
+// $Id: EditVariableDialog.java,v 1.1.1.1 2017/01/04 20:58:10 liu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -742,10 +742,12 @@ public class EditVariableDialog extends JDialog implements ActionListener, CDFCo
 	if (pv.length() != 0) {
 	  if (!pv.equals(padString)) {
 	    try {
-	      Object padValue = CDFToolUtils.parseContent(pv, dataType);
-              var.setPadValue(padValue);
-	      pad = padValue;
-	      padString = pv;
+	      Object padValue = CDFToolUtils.parseContent(pv, dataType, numElements);
+	      if (padValue != null) {
+                var.setPadValue(padValue);
+	        pad = padValue;
+	        padString = pv;
+	      }
             } catch (CDFException ex) {
 	      Toolkit.getDefaultToolkit().beep();
               JOptionPane.showMessageDialog(myFrame,
