@@ -1,3 +1,9 @@
+/******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+
 import java.awt.*;
 import java.awt.event.*;
 import java.text.*;
@@ -439,7 +445,9 @@ public class EditvEntryTablePanel extends JPanel implements CDFConstants {
 		  jj++;
 		  var = (Variable) vars.elementAt(ii);
 	          dataType = en.getDataType();
-	          value = en.getData();
+                  try {
+	            value = en.getData();
+                  } catch (CDFException ex) {}
 		  length = en.getNumElements();	
                   dataObject[jj][0] = var.getName();
 	          dataObject[jj][1] = CDFUtils.getStringDataType(dataType) + "/" + 
