@@ -1,4 +1,4 @@
-// $Id: NewVariableDialog.java,v 1.2 2014/05/14 17:38:06 liu Exp $
+// $Id: NewVariableDialog.java,v 1.1.1.1 2017/01/04 20:58:10 liu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -51,6 +51,7 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 
     private long [] sizes;
     private boolean [] varys;
+    private long numElements;
 
     private Dimension ss;
     private Dimension ps;
@@ -81,7 +82,7 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	});
 
 	setResizable(false);
-	setSize(520,530);
+	setSize(600,530);
 	setLocation(10, 20);
 	setVisible(false);
 
@@ -195,8 +196,9 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
         gbl.setConstraints(jtfcl, gbc);
         osp.add(jtfcl);
 
-        tfpv = new JTextField(10);
-        jtfpv = new JLabeledTF("Pad Value    ", tfpv, true);
+        tfpv = new JTextField(0);
+        jtfpv = new JLabeledTF("Pad Value                                                 ", tfpv, true);
+	jtfpv.set(""+DEFAULT_BYTE_PADVALUE);
         gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.fill = GridBagConstraints.NONE;
         gbl.setConstraints(jtfpv, gbc);
@@ -571,10 +573,50 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	  tfne.setEnabled(true);
 	  jtfne.setVisible(true);
 	  jtfne.setEditable(false); 
-	} 
+	}
+	padValueReset(sl);
       }
     }
 
+    private void padValueReset(String sl) {
+        if (sl.equals("CDF_BYTE")) 
+	  jtfpv.set(""+DEFAULT_BYTE_PADVALUE);
+        else if (sl.equals("CDF_INT1")) 
+	  jtfpv.set(""+DEFAULT_INT1_PADVALUE);
+        else if (sl.equals("CDF_UINT1"))
+	  jtfpv.set(""+DEFAULT_UINT1_PADVALUE);
+        else if (sl.equals("CDF_INT2"))
+	  jtfpv.set(""+DEFAULT_INT2_PADVALUE);
+        else if (sl.equals("CDF_UINT2"))
+	  jtfpv.set(""+DEFAULT_UINT2_PADVALUE);
+        else if (sl.equals("CDF_INT4"))
+	  jtfpv.set(""+DEFAULT_INT4_PADVALUE);
+        else if (sl.equals("CDF_UINT4"))
+	  jtfpv.set(""+DEFAULT_UINT4_PADVALUE);
+        else if (sl.equals("CDF_INT8"))
+	  jtfpv.set(""+DEFAULT_INT8_PADVALUE);
+        else if (sl.equals("CDF_REAL4"))
+	  jtfpv.set(""+DEFAULT_REAL4_PADVALUE);
+        else if (sl.equals("CDF_FLOAT"))
+	  jtfpv.set(""+DEFAULT_FLOAT_PADVALUE);
+        else if (sl.equals("CDF_REAl8"))
+	  jtfpv.set(""+DEFAULT_REAL8_PADVALUE);
+        else if (sl.equals("CDF_DOUBLE"))
+	  jtfpv.set(""+DEFAULT_DOUBLE_PADVALUE);
+        else if (sl.equals("CDF_EPOCH"))
+	  jtfpv.set("01-Jan-0000 00:00:00.000");
+        else if (sl.equals("CDF_EPOCH16"))
+	  jtfpv.set("01-Jan-0000 00:00:00.000.000.000.000");
+        else if (sl.equals("CDF_TIME_TT2000"))
+	  jtfpv.set("0000-01-01T00:00:00.000000000");
+        else if (sl.equals("CDF_CHAR") || sl.equals("CDF_UCHAR")) {
+	  char[] array = new char[ (int)tfne.longValue() ];
+	  for (int ix = 0; ix < tfne.longValue(); ++ix)
+		 array[ix] = DEFAULT_CHAR_PADVALUE;
+	  jtfpv.set("\""+new String(array)+"\"");
+	}
+    }
+
     /**
      * Process button events and change of dimension events.
      */
@@ -601,63 +643,98 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 		if (name != null && name.trim().length() > 0) {
 		  name = name.trim();
 		  switch (cbdt.getIndex()) {
-		    case 0:  dataType = CDF_BYTE;   break;
-		    case 1:  dataType = CDF_INT1;   break;
-		    case 2:  dataType = CDF_UINT1;  break;
-		    case 3:  dataType = CDF_INT2;   break;
-		    case 4:  dataType = CDF_UINT2;  break;
-		    case 5:  dataType = CDF_INT4;   break;
-		    case 6:  dataType = CDF_UINT4;  break;
-		    case 7:  dataType = CDF_INT8;  break;
-		    case 8:  dataType = CDF_REAL4;  break;
-		    case 9:  dataType = CDF_FLOAT;  break;
-		    case 10:  dataType = CDF_REAL8;  break;
+		    case 0:  dataType = CDF_BYTE; break;
+//		             jtfpv.set(""+DEFAULT_BYTE_PADVALUE); break;
+		    case 1:  dataType = CDF_INT1; break;
+//		             jtfpv.set(""+DEFAULT_BYTE_PADVALUE); break;
+		    case 2:  dataType = CDF_UINT1; break;
+//		             jtfpv.set(""+DEFAULT_UINT1_PADVALUE); break;
+		    case 3:  dataType = CDF_INT2; break;
+//		             jtfpv.set(""+DEFAULT_INT2_PADVALUE); break;
+		    case 4:  dataType = CDF_UINT2; break;
+//		             jtfpv.set(""+DEFAULT_UINT2_PADVALUE); break;
+		    case 5:  dataType = CDF_INT4; break;
+//		             jtfpv.set(""+DEFAULT_INT4_PADVALUE); break;
+		    case 6:  dataType = CDF_UINT4; break;
+//		             jtfpv.set(""+DEFAULT_UINT4_PADVALUE); break;
+		    case 7:  dataType = CDF_INT8; break;
+//		             jtfpv.set(""+DEFAULT_INT8_PADVALUE); break;
+		    case 8:  dataType = CDF_REAL4; break;
+//		             jtfpv.set(""+DEFAULT_REAL4_PADVALUE); break;
+		    case 9:  dataType = CDF_FLOAT; break;
+//		             jtfpv.set(""+DEFAULT_FLOAT_PADVALUE); break;
+		    case 10:  dataType = CDF_REAL8; break;
+//		              jtfpv.set(""+DEFAULT_REAL8_PADVALUE); break;
 		    case 11: dataType = CDF_DOUBLE; break;
-		    case 12: dataType = CDF_EPOCH;  break;
-		    case 13: dataType = CDF_EPOCH16;  break;
-		    case 14: dataType = CDF_TIME_TT2000;  break;
-		    case 15: dataType = CDF_CHAR;   break;
-		    case 16: dataType = CDF_UCHAR;  break;
+//		             jtfpv.set(""+DEFAULT_DOUBLE_PADVALUE); break;
+		    case 12: dataType = CDF_EPOCH; break;
+//		             jtfpv.set("01-Jan-0000 00:00:00.000"); break;
+		    case 13: dataType = CDF_EPOCH16; break;
+//		             jtfpv.set("01-Jan-0000 00:00:00.000.000.000.000"); break;
+		    case 14: dataType = CDF_TIME_TT2000; break;
+//		             jtfpv.set("0000-01-01T00:00:00.000000000"); break;
+		    case 15: {
+			     dataType = CDF_CHAR; break;
+//		             char[] array = new char[ (int)tfne.longValue() ];
+//			     for (int ix =0; ix < tfne.longValue(); ++ix)
+//				 array[ix] = DEFAULT_CHAR_PADVALUE;
+//		             jtfpv.set("\""+new String(array)+"\"");
+//			     break;
+			     }
+		    case 16: {
+			     dataType = CDF_UCHAR; break;
+//                             char[] array = new char[ (int)tfne.longValue() ];
+//			     for (int ix =0; ix < tfne.longValue(); ++ix)
+//				 array[ix] = DEFAULT_CHAR_PADVALUE;
+//                             jtfpv.set("\""+new String(array)+"\"");
+//			     break;
+			     }
 		    // keep compiler happy
-		    default: dataType = CDF_BYTE;   break;
+		    default: dataType = CDF_BYTE; break;
+//		             jtfpv.set(""+DEFAULT_BYTE_PADVALUE); break;
 		  }
 
-		  long numElements = 1;
+		  numElements = 1;
 		  if ((dataType == CDF_CHAR) || 
 		    (dataType == CDF_UCHAR))
 		    numElements = tfne.longValue();
-		    
-		  long recVary;
-		  recVary = (cbrv.isSelected() ?
-			   VARY : NOVARY);
 
-		  long [] dimVarys;
-		  long numDims = tfdim.longValue();
-		  switch ((int)numDims) {
-		    case 0:
-		      sizes = new long [] {1};
-		      dimVarys = new long [] {VARY};
-		      break;
-		    case 1:
-		      sizes = new long [1];
-		      dimVarys = new long [1];
-		      sizes[0] = ((Long)jdtsizes.getModel().getData()).
-			longValue();
-		      boolean dv = 
-			((Boolean)jdtvarys.getModel().getData()).booleanValue();
-		      dimVarys[0] = (dv ? VARY : NOVARY);
-		      break;
-		    default:
-		      sizes = (long [])jdtsizes.getModel().getData();
-		      varys = (boolean [])jdtvarys.getModel().getData();
-		      dimVarys = new long[(int)numDims];
-		      for (int i=0;i<(int)numDims;i++)
-			dimVarys[i] = 
-			    (varys[i] ? VARY : NOVARY);
-		      break;
-		  }
-		    
 		  try {
+	            String pv = tfpv.getText();
+	            if (pv != null) pv = pv.trim();
+	            if (pv.length() != 0) {
+	              Object padValue = CDFToolUtils.parseContent(pv, dataType, numElements);
+		    }
+		    long recVary;
+		    recVary = (cbrv.isSelected() ?
+		  	       VARY : NOVARY);
+
+		    long [] dimVarys;
+		    long numDims = tfdim.longValue();
+		    switch ((int)numDims) {
+		      case 0:
+		        sizes = new long [] {1};
+		        dimVarys = new long [] {VARY};
+		        break;
+		      case 1:
+		        sizes = new long [1];
+		        dimVarys = new long [1];
+		        sizes[0] = ((Long)jdtsizes.getModel().getData()).
+		  	            longValue();
+		        boolean dv = 
+			  ((Boolean)jdtvarys.getModel().getData()).booleanValue();
+		        dimVarys[0] = (dv ? VARY : NOVARY);
+		        break;
+		      default:
+		        sizes = (long [])jdtsizes.getModel().getData();
+		        varys = (boolean [])jdtvarys.getModel().getData();
+		        dimVarys = new long[(int)numDims];
+		        for (int i=0;i<(int)numDims;i++)
+		  	  dimVarys[i] = 
+			          (varys[i] ? VARY : NOVARY);
+		        break;
+		    }
+		    
 		    var = Variable.create(cdf,
 					  name,
 					  dataType,
@@ -681,6 +758,13 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 						  "MYEditor: CDFException",
 						  JOptionPane.ERROR_MESSAGE);
 		    var = null;
+                  } catch (NumberFormatException ex) {
+                       Toolkit.getDefaultToolkit().beep();
+                       JOptionPane.showMessageDialog(myFrame,
+                                                     ex.toString(),
+                                                     "MYEditor: Pad value error",
+                                                     JOptionPane.ERROR_MESSAGE);
+		       padValueReset((String) cbdt.get());
 		  }
 		} else {
 		  Toolkit.getDefaultToolkit().beep();
@@ -702,6 +786,7 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	tfdim.setText("0");
 	tfne.setText("1");
 	cbdt.set("CDF_BYTE");
+	jtfpv.set(""+DEFAULT_BYTE_PADVALUE);
 	jtfvn.setEnabled(true);
 	cbdt.setEnabled(true);
 	tfne.setEnabled(true);
@@ -782,7 +867,7 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	if (pv != null) pv = pv.trim();
 	if (pv.length() != 0) {
 	  try {
-	    Object padValue = CDFToolUtils.parseContent(pv, dataType);
+	    Object padValue = CDFToolUtils.parseContent(pv, dataType, numElements);
             var.setPadValue(padValue);
           } catch (CDFException ex) {
 	      Toolkit.getDefaultToolkit().beep();
