@@ -25,6 +25,7 @@ public class SkeletonTable extends JFrame
     JFrame parentDriver;
 /** The dialog for user interface. */
     JDialog dialog;
+    JPanel panelx = new JPanel(new BorderLayout(), true);
 
 /** The FileChooser for the file selection. */
     JFileChooser fileChooser = new JFileChooser();
@@ -353,7 +354,8 @@ public class SkeletonTable extends JFrame
 	cdf.setFont(boldFont);
 	SKLT.setFont(boldFont);
   	sklt.setFont(boldFont);
-	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+//	dialog.getContentPane().add(panel1,BorderLayout.NORTH);
+	panelx.add(panel1,BorderLayout.NORTH);
 	
         // Panel 2
 
@@ -485,7 +487,8 @@ public class SkeletonTable extends JFrame
         variables.addMouseListener(this);
         variables.setToolTipText("Enter comma-separated list of delimited variable names for selected variables"); 
 
-        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+//        dialog.getContentPane().add(panel2,BorderLayout.CENTER);
+        panelx.add(panel2,BorderLayout.CENTER);
 
         // Panel 3 (buttons and text area)
 
@@ -516,9 +519,14 @@ public class SkeletonTable extends JFrame
 		}
 	};
 	scroller.getViewport().add(info);
-	panel3.add(scroller, BorderLayout.SOUTH);
+//	panel3.add(scroller, BorderLayout.SOUTH);
   	info.setVisible(true);
-  	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+//  	dialog.getContentPane().add(panel3, BorderLayout.SOUTH);
+  	panelx.add(panel3, BorderLayout.SOUTH);
+
+        dialog.getContentPane().add(panelx, BorderLayout.NORTH);
+        dialog.getContentPane().add(scroller, BorderLayout.CENTER);
+
     }
 
 /** Implement the run method for Runabout interface.
