@@ -1,4 +1,4 @@
-//$Id: VariableValuePanel.java,v 1.2 2014/05/14 17:38:06 liu Exp $
+//$Id: VariableValuePanel.java,v 1.1.1.1 2017/01/04 20:58:10 liu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -250,17 +250,11 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
     private void showIndexData() {
 
         virtual = false;
-        if (recNum <= maxRec) {
-          try {
-            datavalue = var.getSingleData((long) recNum, dimIndex);
-          } catch (CDFException ex) {
-            datavalue = null;
-          }
+        try {
+          datavalue = var.getSingleData((long) recNum, dimIndex);
 
-          if (sparseRec != NO_SPARSERECORDS) {
-            status = cdf.getStatus();
-            if (status == VIRTUAL_RECORD_DATA) virtual = true;
-          }
+          status = cdf.getStatus();
+          if (status == VIRTUAL_RECORD_DATA) virtual = true;
 
           if (dataType == CDF_EPOCH)
             output = Epoch.encode(((Double)datavalue).doubleValue());
@@ -295,74 +289,14 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 	      }
 	    }
 	  }
-        } else {
-	  virtual = true;
-          if (padValue == null) {
-            switch ((int)dataType) {
-              case (int) CDF_BYTE:
-              case (int) CDF_INT1:
-              case (int) CDF_UINT1:
-              case (int) CDF_INT2:
-              case (int) CDF_UINT2:
-              case (int) CDF_INT4:
-              case (int) CDF_UINT4:
-              case (int) CDF_INT8:
-                output = "0";
-                break;
-              case (int) CDF_REAL4:
-              case (int) CDF_FLOAT:
-              case (int) CDF_DOUBLE:
-                output = "0.0000";
-                break;
-              case (int) CDF_EPOCH:
-                output = "01-Jan-0000 00:00:00.000";
-                break;
-              case (int) CDF_EPOCH16:
-                output = "01-Jan-0000 00:00:00.000.000.000.000";
-                break;
-              case (int) CDF_TIME_TT2000:
-                output = "0000-01-01T00:00:00.000.000000000";
-                break;
-              case (int) CDF_CHAR:
-              case (int) CDF_UCHAR:
-		StringBuffer tmp = new StringBuffer();
-		tmp.append("\"");
-		for (int i = 0; i < (int) numElements; i++)
-		  tmp.append(" ");
-		tmp.append("\"");
-                output = tmp.toString();
-                break;
-            }
-          } else {
-            if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16 &&
-                dataType != CDF_TIME_TT2000) 
-		output = padValue.toString();
-            else {
-		if (dataType == CDF_EPOCH) {
-                  if (padValue instanceof String) output = (String) padValue;
-                  else {
-                    double epoch = ((Double)padValue).doubleValue();
-                    if (epoch < 0.0) epoch = 0.0;
-                    output = Epoch.encode(epoch);
-                  }
-		} else if (dataType == CDF_EPOCH16) {
-                  if (padValue instanceof String) output = (String) padValue;
-                  else {
-                    output = Epoch16.encode((double[])padValue);
-                  }
-		} else {
-                  if (padValue instanceof String) output = (String) padValue;
-                  else {
-                    long epoch = ((Long)padValue).longValue();
-                    output = CDFTT2000.toUTCstring(epoch);
-                  }
-                }
-            }
-          }
+        } catch (CDFException ex) {
+          Toolkit.getDefaultToolkit().beep();
+          JOptionPane.showMessageDialog(myEditor.getFrame(),
+                                        "Exception:"+cdf.getStatus());
         }
 	jtfVal.set((virtual) ? output+ "     " + Virtual : output);
-	update.setEnabled(false);
-	cancel.setEnabled(false);
+	update.setEnabled(true);
+	cancel.setEnabled(true);
     }
 
     public void reset() {
@@ -445,10 +379,12 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 		boolean changed = false;
 		int ick = newValue.toLowerCase().indexOf("<virtual>");
 		if (ick != -1) {
-		   newActualValue = newValue.substring(0, ick-1).trim(); 
+		   valueX = CDFToolUtils.parseContent(newValue.substring(0, ick-1).trim(), dataType, numElements); 
 		   jtfVal.set(newValue);
 		} else
-		   newActualValue = new String(newValue);
+		   valueX = CDFToolUtils.parseContent(newValue, dataType, numElements);
+		changed = true;
+/*
                 switch ((int)dataType) {
                 case (int) CDF_BYTE:
                 case (int) CDF_INT1:   
@@ -535,6 +471,7 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 			valueX = null;
 			break;
               }
+*/
 	      if (changed) {
 	        var.putSingleData(recNum, dimIndex, valueX);
 	        if ((sparseRec == NO_SPARSERECORDS && recNum > maxRec) || 
@@ -555,6 +492,7 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 		    myEditor.vAttrPanel.getRightPanel().revalidate();
 		    myEditor.vAttrPanel.getRightPanel().repaint();
 		  }
+                  showIndexData();
 		}
 	      }
 	    } catch (CDFException ex) {
@@ -563,12 +501,18 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
                                             CDFException.getStatusMsg(ex.getCurrentStatus()),
                                             "MYEditor: CDFException",
                                             JOptionPane.ERROR_MESSAGE);
+                showIndexData();
+                update.setEnabled(true);
+                cancel.setEnabled(true);
 	    } catch (NumberFormatException ex) {
 		Toolkit.getDefaultToolkit().beep();
                 JOptionPane.showMessageDialog(myEditor.getFrame(),
                                             ex.toString(),
                                             "MYEditor: CDFException",
                                             JOptionPane.ERROR_MESSAGE);
+                showIndexData();
+                update.setEnabled(true);
+                cancel.setEnabled(true);
 	    }
 	  }
 	}
