@@ -1,3 +1,9 @@
+/******************************************************************************
+* Copyright 1996-2013 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+
 import java.io.*;
 import java.text.*;
 import java.util.*;
@@ -174,20 +180,30 @@ public class CreateCDF implements CDFConstants{
                                  new long [] {VARY}),
 
             ep = Variable.create(cdf, "ep", CDF_EPOCH, 
-                                 1, 1, new long [] {2},
+                                 1, 0, new long [] {0},
                                  VARY, 
-                                 new long [] {VARY}),
+                                 new long [] {NOVARY}),
 
             ep16 = Variable.create(cdf, "ep16", CDF_EPOCH16, 
                                  1, 0, new long [] {0},
                                  VARY, 
+                                 new long [] {NOVARY}),
+
+            newI8 = Variable.create(cdf, "newI8", CDF_INT8, 
+                                 1, 1, new long [] {2},
+                                 VARY, 
                                  new long [] {VARY}),
 
+            tt2000 = Variable.create(cdf, "tt2000", CDF_TIME_TT2000, 
+                                 1, 0, new long [] {0},
+                                 VARY, 
+                                 new long [] {NOVARY}),
+
             dummyVar = Variable.create(cdf, "DummyVar", 
                                        CDF_EPOCH, 
-                                       1, 1, new long [] {2},
+                                       1, 0, new long [] {0},
                                        VARY, 
-                                       new long [] {VARY});
+                                       new long [] {NOVARY});
 
           System.out.println("Created variables.");
                 
@@ -219,9 +235,10 @@ public class CreateCDF implements CDFConstants{
 
           longitude.selectCacheSize(700L);
           longitude.setCompression(GZIP_COMPRESSION, new long[] {9});
-          longitude.setPadValue(new Short((short) -99));
+//          longitude.setPadValue(new Short((short) -99));
           longitude.setBlockingFactor(130L);
           longitude.setInitialRecords(20L);
+System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus()+" confirm="+longitude.confirmPadValue());
 
           // Only applicable to compressed z variables
           longitude.selectReservePercent(15L);   
@@ -255,7 +272,7 @@ public class CreateCDF implements CDFConstants{
 
           System.out.println("Adding global attribute entries...");
         
-          Entry.create(project, 0, CDF_CHAR, "Using the CDFJava API");
+          Entry.create(project, 0, CDF_CHAR, "Using the CDFJava ƒ ∑ API");
           Entry.create(pi, 3, CDF_CHAR, "Ernie Els");
           System.out.println("\tchars completed.");
 
@@ -308,6 +325,10 @@ public class CreateCDF implements CDFConstants{
           Entry.create(ep16TestDate, 0, CDF_EPOCH16, ep16Data);
           System.out.println("\tEPOCH16 completed.");
 
+          long testTT2000  = CDFTT2000.compute(2008, 2, 4, 6, 8, 10, 12, 14, 16);
+          Entry.create(testDate, 2, CDF_TIME_TT2000,
+                       new Long(testTT2000));
+          System.out.println("\tEPOCH completed.");
 
           /************************************/
           /*  Add variable attribute entries  */
@@ -332,7 +353,6 @@ public class CreateCDF implements CDFConstants{
           ep.putEntry(dummy,  CDF_EPOCH, new Double(testDateData1));
           System.out.println("\tAdded dummy for ep.");
 
-         
           ep_status  = Epoch16.compute(2002L, 5L, 13L, 15L, 8L, 
                                        1L, 2L, 3L, 4L, 5L, ep16Data);
           ep16.putEntry(dummy,  CDF_EPOCH16, ep16Data);
@@ -341,7 +361,12 @@ public class CreateCDF implements CDFConstants{
           longitude.putEntry(dummy,  CDF_CHAR, "test2");
           System.out.println("\tAdded dummy for Longitude.");
 
-          char ch = 10;      // Line feed
+          long testDateData2  = CDFTT2000.compute(2010, 5, 13, 10, 20, 30, 40,
+                                                  50, 60);
+          tt2000.putEntry(dummy,  CDF_TIME_TT2000, new Long(testDateData2));
+          System.out.println("\tAdded dummy for tt2000.");
+
+          char ch = 'a'; 
           String myStr = String.valueOf(ch); 
           longitude.putEntry(myAttr,  CDF_CHAR, myStr);
           System.out.println("\tAdded myAttr for Longitude.");
@@ -512,6 +537,7 @@ public class CreateCDF implements CDFConstants{
           /*********************/
           /*  Add String data  */
           /*********************/
+	  name.setPadValue(new String("abc"));
           String [] ndata = new String[2];
           ndata[0] = "abcd";
           ndata[1] = "bcdefghij";
@@ -608,13 +634,13 @@ public class CreateCDF implements CDFConstants{
           /*****************/
           /*  Add ep data  */
           /*****************/
-          double epData  = Epoch.compute(1999, 3, 5, 5, 0, 0, 0),
-                 epData1 = Epoch.compute(1998, 1, 2, 3, 0, 0, 0);
+          double epData  = Epoch.compute(1999, 3, 5, 5, 6, 7, 100),
+                 epData1 = Epoch.compute(1998, 1, 2, 3, 4, 5, 666);
           String e0 = Epoch.encode(epData1);
           double p0 = Epoch.parse(e0);
 
           ep.putSingleData(0L, new long[] {0}, new Double(epData)); 
-          ep.putSingleData(0L, new long[] {1}, new Double(p0)); 
+          ep.putSingleData(1L, new long[] {0}, new Double(p0)); 
 
           System.out.println("\tAdded putSingleData ep data.");
 
@@ -630,8 +656,72 @@ public class CreateCDF implements CDFConstants{
                                        ep16Data);        /* CDF_EPOCH16 data */
           ep16.putSingleData(0L, new long[] {0}, ep16Data);
 
+          ep_status  = Epoch16.compute(2004, 12, 29,     /* yyyy-mm-dd */
+                                       16, 56, 24,       /* hh-mm-ss   */
+                                       31,               /* millisecond */
+                                       411,              /* microsecond */
+                                       522,              /* nanosecond  */
+                                       634,              /* picosecond  */
+                                       ep16Data);        /* CDF_EPOCH16 data */
+          ep16.putSingleData(1L, new long[] {0}, ep16Data);
+
+          ep_status  = Epoch16.compute(2005, 12, 29,     /* yyyy-mm-dd */
+                                       16, 56, 24,       /* hh-mm-ss   */
+                                       31,               /* millisecond */
+                                       444,              /* microsecond */
+                                       555,              /* nanosecond  */
+                                       777,              /* picosecond  */
+                                       ep16Data);        /* CDF_EPOCH16 data */
+          ep16.putSingleData(2L, new long[] {0}, ep16Data);
+
           System.out.println("\tAdded putSingleData ep16 data.");
 
+          /********************/
+          /*  Add newI8 data  */
+          /********************/
+          
+          long [][] i8Data = {{1L,  -1L},
+                              {10L, -10L},
+                              {Long.MAX_VALUE, Long.MIN_VALUE}};
+
+          newI8.putSingleData(0L, new long[] {0}, new Long(88888L));
+          newI8.putSingleData(0L, new long[] {1}, new Long(99999L));
+
+          System.out.println("\tAdded a single newI8 data.");
+
+          newI8.putHyperData(1L, 3L, 1L,
+                             new long[] {0}, new long[] {2}, new long[] {1},
+                             i8Data);
+
+          System.out.println("\tAdded hyperput newI8 data.");
+
+          /*********************/
+          /*  Add tt2000 data  */
+          /*********************/
+          
+          String dateTime = new String("2015-06-30T23:59:58.123456789");
+          long [] nanosecs = new long[5];
+          long nansecSinceJ2000;
+          try {
+            nansecSinceJ2000 = CDFTT2000.fromUTCstring(dateTime);
+          } catch (CDFException ex) {
+            nansecSinceJ2000 = 0;
+          }
+          int ix;
+          for (ix = 0; ix < 5; ++ix) {
+             nanosecs[ix] = nansecSinceJ2000 + (ix + 1) * 1000000000L;
+          }
+
+          tt2000.putSingleData(0L, new long[] {0}, new Long(nansecSinceJ2000));
+
+          System.out.println("\tAdded a single tt2000  data.");
+
+          tt2000.putHyperData(1L, 5L, 1L,
+                              new long[] {0}, new long[] {1}, new long[] {1},
+                              nanosecs);
+
+          System.out.println("\tAdded hyperput tt2000 data.");
+
           /************************************************************/
           /* Initiate a record write for a group of CDF variables.    */
           /* Six (6) variables are involved in this data put function */
