@@ -94,6 +94,11 @@ public class ReadCDF implements CDFConstants{
               System.out.println("Compression:  "+cdf.getCompression());
               if (cdf.getCompressionType() != 0)
                 System.out.println("cPct:         "+cdf.getCompressionPct());
+              if (new Integer(cdf.getVersion().substring(0,1)).intValue() > 3) {
+                long lsLastUpdated = cdf.getLeapSecondLastUpdated();
+                if (lsLastUpdated > 0)
+		  System.out.println("LeapSecondLastUpdated:     "+lsLastUpdated);
+              }
               System.out.println("Cache Size:   "+cdf.confirmCDFCacheSize());
   
               /**********************************************/
