@@ -256,6 +256,9 @@ public interface CDFConstants {
     public static final long MULTI_FILE_FORMAT            = 1007;
     public static final long SOME_ALREADY_ALLOCATED       = 1008;
     public static final long PRECEEDING_RECORDS_ALLOCATED = 1009;
+    public static final long TT2000_CDF_MAYNEEDUPDATE     = 1010;
+    public static final long BLOCKINGFACTOR_TOO_SMALL     = 1011;
+    public static final long BLOCKINGFACTOR_TOO_SMALL2    = 1012;
 
     public static final long CDF_OK                       = 0;
 
@@ -392,6 +395,13 @@ public interface CDFConstants {
     public static final long IS_A_NETCDF                  = -2228;
     public static final long TT2000_TIME_ERROR            = -2229;
     public static final long UNABLE_TO_PROCESS_CDF        = -2230;
+    public static final long ZLIB_COMPRESS_ERROR          = -2231;
+    public static final long ZLIB_UNCOMPRESS_ERROR        = -2232;
+    public static final long CANNOT_INSERT_RECORDS        = -2233;
+    public static final long TT2000_USED_OUTDATED_TABLE   = -2234;
+    public static final long BADDATE_LEAPSECOND_UPDATED   = -2235;
+    public static final long FUNCTION_NOT_SUPPORTED       = -2236;
+
 
     /*----------------------------------------------------------------*/
     /*  Functions (for INTERNAL interface).                           */
@@ -580,6 +590,7 @@ public interface CDFConstants {
     public static final long CDF_CHECKSUM_ =            156;
     public static final long rVAR_RECORDS_RENUMBER_ =   157;
     public static final long zVAR_RECORDS_RENUMBER_ =   158;
+    public static final long CDF_LEAPSECONDLASTUPDATED_ = 159;
 
     public static final long CDFwithSTATS_ = 200;   /* For CDF internal use only! */
     public static final long CDF_ACCESS_ =   201;   /* For CDF internal use only! */
