@@ -1,6 +1,5 @@
-// $Id: CDFException.java,v 1.2 2014/05/14 17:38:29 liu Exp $
 /*
- * Copyright 1996-2014 United States Government as represented by the
+ * Copyright 1996-2015 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
  * All Rights Reserved.
  */
@@ -105,6 +104,8 @@ public class CDFException
 	msgs.put(new Long(CANNOT_COPY), "The source/destination variables "+
 		 "have a different dataType/numElements/numDims/dimSizes/"+
 		 "dimVariances.");
+	msgs.put(new Long(CANNOT_INSERT_RECORDS), "Cannot insert records to " +
+		 "a variable with sparserecords..");
 	msgs.put(new Long(CANNOT_SPARSEARRAYS), "Sparse arrays can't be "+
 		 "set/modified for the variable.");
 	msgs.put(new Long(CANNOT_SPARSERECORDS), "Sparse records can't be "+
@@ -203,6 +204,12 @@ public class CDFException
 		 "encountered.");
 	msgs.put(new Long(TOO_MANY_VARS), "Only a limited number of "+
 		 "variables may exist in this CDF.");
+	msgs.put(new Long(TT2000_CDF_MAYNEEDUPDATE), "CDF version or its file-based template " +
+		 "may need to upgrade to handle TT2000 data properly (even its TT2000 " +
+                 "value may be valid).");
+	msgs.put(new Long(TT2000_USED_OUTDATED_TABLE), "A TT2000 data "+
+		 "is either invalid (made with an oudated leap second " +
+                 "table) or trying to use an outdated table.");
 	msgs.put(new Long(UNKNOWN_COMPRESSION), "An unknown type of "+
 		 "compression was encountered.");
 	msgs.put(new Long(UNKNOWN_SPARSENESS), "An unknown sparseness was"+
@@ -242,17 +249,31 @@ public class CDFException
 	msgs.put(new Long(CHECKSUM_NOT_ALLOWED), "The checksum is not allowed"+
 		" for old versioned files.");
 	msgs.put(new Long(IS_A_NETCDF), "Named CDF is actually a netCDF file.");
-        msgs.put(new Long(TT2000_TIME_ERROR), "Error handling the date/time "+
+        msgs.put(new Long(TT2000_TIME_ERROR), "Error handling the date/time " +
                  "for TT2000 or a TT2000 epoch."); 
-        msgs.put(new Long(UNABLE_TO_PROCESS_CDF), "One of data fields is "+
+        msgs.put(new Long(UNABLE_TO_PROCESS_CDF), "One of data fields is " +
                  "invalid... Upgrade the library might fix the problem.");
+        msgs.put(new Long(ZLIB_COMPRESS_ERROR), "ZLIB_ERROR: Error during " +
+                 "ZLIB compression.");
+        msgs.put(new Long(ZLIB_UNCOMPRESS_ERROR), "ZLIB_ERROR: Error during " +
+                 "ZLIB compression.");
+        msgs.put(new Long(TT2000_USED_OUTDATED_TABLE), "TT2000_USED_OUTDATED_TABLE: " +
+		 "A TT2000 data is either invalid (made with an oudated leap second table) or trying to use an outdated leap second table.");
+        msgs.put(new Long(BADDATE_LEAPSECOND_UPDATED), "BADDATE_LEAPSECOND_UPDATED: " +
+		 "The last leap second updated date is not valid (not in the leap second table).");
+        msgs.put(new Long(FUNCTION_NOT_SUPPORTED), "FUNCTION_NOT_SUPPORTED: This function " +
+                 "is not supported. Likely, it is trying to access an rVariable.");
+        msgs.put(new Long(BLOCKINGFACTOR_TOO_SMALL), "BLOCKINGFACTOR_TOO_SMALL: " +
+                 "The blocking factor set for the compressed variable is smaller than the default. It is changed but may make data access ineffective.");
+        msgs.put(new Long(BLOCKINGFACTOR_TOO_SMALL2), "BLOCKINGFACTOR_TOO_SMALL2: " +
+                 "The variable's blocking factor is smaller than the default if it is compressed. The compression is set but may make data access ineffective.");
     }
 
     /**
      * Takes a text message from the calling program and throws a
      * CDFException.
      *
-     * @param message the message to be thrown with CDFException <P>
+     * @param message the message to be thrown with CDFException 
      */
     public CDFException(String message) {
 	super(message);
@@ -262,7 +283,7 @@ public class CDFException
      * Takes a status code and throws a CDFException with the message
      * that corresponds to the status code that is passed in. 
      * 
-     * @param statusCode the CDF statusCode to be thrown <P>
+     * @param statusCode the CDF statusCode to be thrown 
      */
     public CDFException(long statusCode) {
 	this(statusCode, null);
@@ -274,7 +295,7 @@ public class CDFException
      * It also specifies where (which routine) the problem was. 
      *
      * @param statusCode the CDF statusCode to be thrown <P>
-     * @param where the place (routine/method) where the problem occurred <P>
+     * @param where the place (routine/method) where the problem occurred 
      *
      */
     public CDFException(long statusCode, String where) {
@@ -307,7 +328,7 @@ public class CDFException
      *             e.printStackTrace();
      *          }
      *    }
-     *
+     * </PRE>
      * @return the status code that caused CDFException
      */
     public long getCurrentStatus() {
