@@ -1,4 +1,4 @@
-// $Id: CDFTools.java,v 1.3 2014/08/01 14:45:44 liu Exp $
+// $Id: CDFTools.java,v 1.1.1.1 2017/01/04 20:58:09 liu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -19,7 +19,7 @@ import gsfc.nssdc.cdf.util.*;
  * Created: Tue Nov 24 16:14:50 1998
  *
  * @author Phil Williams
- * @version $Id: CDFTools.java,v 1.3 2014/08/01 14:45:44 liu Exp $
+ * @version $Id: CDFTools.java,v 1.1.1.1 2017/01/04 20:58:09 liu Exp $
  */
 
 public class CDFTools implements CDFConstants {
@@ -50,7 +50,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table
      *            to be created.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the CDF from which the skeleton table
@@ -123,6 +123,11 @@ public class CDFTools implements CDFConstants {
      * @param cacheSize The number of buffers to be used for the CDF's dotCDF
      *            file. Pass 0 to use the default. <BR> <BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -164,7 +169,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table
      *            to be created.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the CDF from which the skeleton table
@@ -240,6 +245,11 @@ public class CDFTools implements CDFConstants {
      * @param cacheSizeS The number of buffers to be used for the CDF's staging
      *            file. Pass 0 to use the default. <BR> <BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -287,7 +297,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table
      *            to be created.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the CDF from which the skeleton table
@@ -366,6 +376,11 @@ public class CDFTools implements CDFConstants {
      * @param cacheSizeC The number of buffers to be used for the CDF's
      *            compression scratch file. Pass 0 to use the default. <BR> <BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -419,7 +434,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table
      *            to be created.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the CDF from which the skeleton table
@@ -496,18 +511,23 @@ public class CDFTools implements CDFConstants {
      *            likely reduce physical I/Os if variable data are involved. 
      *            If this field is null, the default cache sizes chosen by
      *            the CDF library are used.  The cache sizes are specified
-     *            with a comma-separated list of <number><type> pairs where
-     *            <number> is the number of cache buffers and <type> is the
-     *            type of file.  The file <type>'s are as follows: `d' for
+     *            with a comma-separated list of &lt;number&gt;&lt;type&gt; pairs where
+     *            &lt;number&gt; is the number of cache buffers and &lt;type&gt; is the
+     *            type of file.  The file &lt;type&gt;'s are as follows: `d' for
      *            the dotCDF file, `s' for the staging file, and `c' for the
      *            compression scratch file.  For example, `200d,100s'
      *            specifies 200 cache buffers for the dotCDF file and 100
      *            cache buffers for the staging file.  The dotCDF file cache
-     *            size can also be specified without the `d' <type> for
+     *            size can also be specified without the `d' &lt;type&gt; for
      *            compatibility with older CDF releases (eg. `200,100s').
      *            Note that not all of the file types must be specified.
      *            Those not specified will receive a default cache size.<BR><BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -580,12 +600,12 @@ public class CDFTools implements CDFConstants {
 	if (reportType != 0) {
 	    cmd.append("-report \"");
 	    if ((reportType & REPORT_ERRORS) != 0)
-		cmd.append("errors, ");
+		cmd.append("errors,");
 	    if ((reportType & REPORT_WARNINGS) != 0)
-		cmd.append("warnings, ");
+		cmd.append("warnings,");
 	    if ((reportType & REPORT_INFORMATION) != 0)
-		cmd.append("informationals, ");
-	    cmd.setLength(cmd.length()-2); // chop off the last 2 chars
+		cmd.append("informationals,");
+	    cmd.setLength(cmd.length()-1); // chop off the last 2 chars
 	    cmd.append("\" ");
 	}
 
@@ -632,7 +652,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table to be used
      *            to create a CDF.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the created CDF from the skeleton table.
@@ -677,6 +697,11 @@ public class CDFTools implements CDFConstants {
      * @param cacheSizeD The number of buffers to be used for the CDF's
      *            dotCDF file. Pass 0 to use the default. <BR> <BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -715,7 +740,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table to be used
      *            to create a CDF.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the created CDF from the skeleton table.
@@ -763,6 +788,11 @@ public class CDFTools implements CDFConstants {
      * @param cacheSizeS The number of buffers to be used for the CDF's
      *            staging file. Pass 0 to use the default. <BR> <BR>
      *
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
+     *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
      *    this <b>cdf.base</b> system property is defined (to the cdf installation).
@@ -807,7 +837,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table to be used
      *            to create a CDF.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the created CDF from the skeleton table.
@@ -857,6 +887,10 @@ public class CDFTools implements CDFConstants {
      *
      * @param cacheSizeC The number of buffers to be used for the CDF's
      *            compression scratch file. Pass 0 to use the default. <BR> <BR>
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
      *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
@@ -909,7 +943,7 @@ public class CDFTools implements CDFConstants {
      * @param skeletonName is the pathname of the skeleton table to be used
      *            to create a CDF.  (Do not enter an extension because ".skt"
      *            is appended automatically).  If <B>null</B> is specified, the
-     *            skeleton table is named <cdfName>.skt in the current
+     *            skeleton table is named &lt;cdfName&gt;.skt in the current
      *            directory<BR><BR>
      *
      * @param cdfName The pathname of the created CDF from the skeleton table.
@@ -958,17 +992,21 @@ public class CDFTools implements CDFConstants {
      *            reduce physical I/Os if variable data are involved.
      *            If this field is null, default cache sizes chosen by
      *            the CDF library are used.  The cache sizes are specified
-     *            with a comma-separated list of <number><type> pairs where
-     *            <number> is the number of cache buffers and <type> is the
-     *            type of file.  The file <type>'s are as follows: `d' for
+     *            with a comma-separated list of &lt;number&gt;&lt;type&gt; pairs where
+     *            &lt;number&gt; is the number of cache buffers and &lt;type&gt; is the
+     *            type of file.  The file &lt;type&gt;'s are as follows: `d' for
      *            the dotCDF file, `s' for the staging file, and `c' for the
      *            compression scratch file.  For example, `200d,100s'
      *            specifies 200 cache buffers for the dotCDF file and 100
      *            cache buffers for the staging file.  The dotCDF file cache
-     *            size can also be specified without the `d' <type> for
+     *            size can also be specified without the `d' &lt;type&gt; for
      *            compatibility with older CDF releases (eg. `200,100s').
      *            Note that not all of the file types must be specified.
      *            Those not specified will receive a default cache size.<BR><BR>
+     * @throws java.io.IOException An exception is thrown if the file is bad
+     *                             or non-existent
+     * @throws InterruptedException An exception is thrown if an interrupt is
+     *                              issued
      *
      * <B>Note:</B><BR>
      *    When running an application that use this static method, make sure
@@ -1016,15 +1054,15 @@ public class CDFTools implements CDFConstants {
 	cmd.append("neg2posfp0 ");
 
 	if (reportType != 0) {
-	    cmd.append("-report ");
+	    cmd.append("-report \"");
 	    if ((reportType & REPORT_ERRORS) != 0)
-		cmd.append("errors, ");
+		cmd.append("errors,");
 	    if ((reportType & REPORT_WARNINGS) != 0)
-		cmd.append("warnings, ");
+		cmd.append("warnings,");
 	    if ((reportType & REPORT_INFORMATION) != 0)
-		cmd.append("informationals, ");
-	    cmd.setLength(cmd.length()-2); // chop off the last 2 chars
-	    cmd.append(" ");
+		cmd.append("informationals,");
+	    cmd.setLength(cmd.length()-1); // chop off the last 2 chars
+	    cmd.append("\" ");
 	}
 
 	if (cacheSize != null) {
@@ -1050,6 +1088,7 @@ public class CDFTools implements CDFConstants {
 	    if (err instanceof PrintStream)
 		((PrintStream)err).println(line);
 	}
+
     }
 
     /**
