@@ -1,6 +1,5 @@
-//$Id: Entry.java,v 1.6 2014/05/22 14:11:50 liu Exp $
 /*
- * Copyright 1996-2014 United States Government as represented by the
+ * Copyright 1996-2015 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
  * All Rights Reserved.
  */
@@ -67,6 +66,7 @@ public class Entry extends Object implements CDFObject, CDFConstants {
      * The entry data
      */
     private Object data = null;
+    private Object xdata = null;
 
     /**
      * Since the data is a generic object and is set on-the-fly, this holds
@@ -101,7 +101,7 @@ public class Entry extends Object implements CDFObject, CDFConstants {
      * @param id The entry id <P>
      *
      * @return The requested attribute entry <P>
-     * @exception CDFException If there is a problem getting the entry
+     * @throws CDFException CDFException If there is a problem getting the entry
      */
     protected static Entry retrieve(Attribute myAttribute, long id) 
 	throws CDFException
@@ -162,8 +162,6 @@ synchronized(myAttribute) {
         /********************/
 	/* Get the data out */
         /********************/
-/* Not do it now... Perform it in getData method, instead. */
-/*
 	theEntry.buildDataObject();
 	cmds.removeAllElements();
 	item0.removeAllElements();
@@ -197,7 +195,7 @@ synchronized(myAttribute) {
 
 	theEntry.myAttribute.getMyCDF().
 	    executeCommand((CDFObject)theEntry, cmds);
-*/
+
 	myAttribute.addEntry(theEntry, (int)id);
 	return theEntry;
     }
@@ -223,8 +221,8 @@ synchronized(myAttribute) {
      *     Attribute validMin = Attribute.create(cdf, "VALIDMIN", 
      *                                           VARIABLE_SCOPE);
      *     Entry.create(validMin, longitude.getID(), CDF_INT2, 
-     *                  new Short((short)10)); <P>
-     *             OR <P>
+     *                  new Short((short)10)); 
+     *             OR 
      *     longitude.putEntry(validMin, CDF_INT2, new Short((short)180));
      * </PRE>
      *
@@ -254,7 +252,7 @@ synchronized(myAttribute) {
      * @param data the entry data to be added <P>
      *
      * @return newly created attribute entry <P>
-     * @exception CDFException if there is a problem creating an entry
+     * @throws CDFException CDFException if there is a problem creating an entry
      */
     public static Entry create(Attribute myAttribute, long id, 
 			       long dataType, Object data) 
@@ -276,7 +274,8 @@ synchronized(myAttribute) {
         // data type and numElements of an existing entry.
 
         if (myAttribute.getMaxEntryNumber() > id) {
-            try { myAttribute.getEntry(id).delete(); }
+            try { Entry entry = (Entry) myAttribute.getEntry(id);
+                  if (entry != null) entry.delete(); }
             catch (CDFException e) {}
         }
 
@@ -431,7 +430,7 @@ synchronized(myAttribute) {
     /**
      * Deletes this entry.
      *
-     * @exception CDFException if there is a problem deleting this entry
+     * @throws CDFException CDFException if there is a problem deleting this entry
      */
     public synchronized void delete() throws CDFException {
 
@@ -500,53 +499,105 @@ synchronized(myAttribute) {
     }
 
     /**
-     * Gets the data for this entry.
+     * Gets the data for this entry. Build a new data object so a duplicated
+     * variable will have its own copy of the entry data.
      *
      * @return the data for this entry 
+     *
+     * @throws CDFException An exception is thrown if the operation fails
      */
     public synchronized Object getData() throws CDFException {
-        Vector cmds = new Vector();
-        Vector item0 = new Vector();
-        Vector item1 = new Vector();
-        Vector itemA = new Vector();
-        Vector itemB = new Vector();
-        Vector itemC = new Vector();
 
-        /********************/
-        /* Get the data out */
-        /********************/
-        this.buildDataObject();
-
-        cmds.addElement(new Long(SELECT_));
-          cmds.addElement(new Long(CDF_));
-            itemA.addElement("cdfID");
-            itemA.addElement("J");
-          cmds.addElement(itemA);
-          cmds.addElement(new Long(ATTR_));
-            itemB.addElement("attrID");
-            itemB.addElement("J");
-          cmds.addElement(itemB);
-          cmds.addElement(((this.scope == GLOBAL_SCOPE) ?
-                           new Long(gENTRY_) : new Long(zENTRY_)));
-            itemC.addElement("id");
-            itemC.addElement("J");
-          cmds.addElement(itemC);
-
-        cmds.addElement(new Long(GET_));
-          cmds.addElement(((this.scope == GLOBAL_SCOPE) ?
-                           new Long(gENTRY_DATA_) :
-                           new Long(zENTRY_DATA_)));
-            item0.addElement("data");
-            item0.addElement("Ljava/lang/Object;");
-          cmds.addElement(item0);
-        cmds.addElement(new Long(NULL_));
-
-        this.myAttribute.getMyCDF().
-            executeCommand((CDFObject)this, cmds);
-
-	return data;
+      try {
+	if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
+	    String data2 = new String(((String)data).toString());
+            return data2;
+	} else {
+	  switch ((int)dataType) {
+	    case (int)CDF_BYTE:
+	    case (int)CDF_INT1:
+		if (numElements > 1) {
+		    byte[] data2 = new byte [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((byte[]) data)[i];
+		    return data2;
+	        } else {
+		    Byte data2 = new Byte(((Byte)data).byteValue());
+		    return data2;
+		}
+	    case (int)CDF_INT2:
+	    case (int)CDF_UINT1:
+		if (numElements > 1) {
+		    short[] data2 = new short [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((short[]) data)[i];
+		    return data2;
+		} else {
+		    Short data2 = new Short(((Short)data).shortValue());
+		    return data2;
+		}
+	    case (int)CDF_INT4:
+	    case (int)CDF_UINT2:
+		if (numElements > 1) {
+		    int[] data2 = new int [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((int[]) data)[i];
+		    return data2;
+		} else {
+		    Integer data2 = new Integer(((Integer)data).intValue());
+		    return data2;
+		}
+	    case (int)CDF_UINT4:
+	    case (int)CDF_INT8:
+	    case (int)CDF_TIME_TT2000:
+		if (numElements > 1) {
+		    long[] data2 = new long [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((long[]) data)[i];
+		    return data2;
+		} else {
+		    Long data2 = new Long(((Long)data).longValue());
+		    return data2;
+		}
+	    case (int)CDF_REAL4:
+	    case (int)CDF_FLOAT:
+		if (numElements > 1) {
+		    float[] data2 = new float [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((float[]) data)[i];
+		    return data2;
+		} else {
+		    Float data2 = new Float(((Float)data).floatValue());
+		    return data2;
+		}
+	    case (int)CDF_REAL8:
+	    case (int)CDF_DOUBLE:
+	    case (int)CDF_EPOCH:
+		if (numElements > 1) {
+		    double[] data2 = new double [(int)numElements];
+		    for (int i=0;i<(int)numElements;++i)
+			data2[i] = ((double[]) data)[i];
+		    return data2;
+		} else {
+		    Double data2 = new Double(((Double)data).doubleValue());
+		    return data2;
+		}
+            case (int)CDF_EPOCH16:
+                double[] data2 = new double [2*(int)numElements];
+		for (int i=0;i<(int)numElements;++i) {
+		   data2[2*i] = ((double[]) data)[2*i];
+		   data2[2*i+1] = ((double[]) data)[2*i+1];
+		}
+		return data2;
+	    default:
+		break;
+	    /* switch (dataType) */
+	  }
+	}
+	return null;
+      } catch (Exception ex) {throw new CDFException(DATATYPE_MISMATCH);}
     }
-    
+	
     /**
      * Gets the ID of this entry.
      *
@@ -578,7 +629,7 @@ synchronized(myAttribute) {
      * implements the CDFObject interface that includes "rename".  
      *
      * @param name - not applicable <P>
-     * @exception CDFException - not applicable 
+     * @throws CDFException CDFException - not applicable 
      */
     public synchronized void rename(String name) throws CDFException {
     }
@@ -586,6 +637,9 @@ synchronized(myAttribute) {
      * Update the data specification (data type and number of elements)
      * of the entry.
      *
+     * @param  dataType the data type of the entry data
+     * @param  numElements the number of elements of the entry data
+     * @throws CDFException An exception is thrown if the operation fails
      */
     public synchronized void updateDataSpec(long dataType, long numElements) 
 	throws CDFException {
@@ -674,6 +728,10 @@ synchronized(myAttribute) {
     /**
      * Put the entry data into the CDF.
      *
+     * @param  dataType the data type of the entry data
+     * @param  data the entry data to write
+     * @throws CDFException An exception is thrown if the operation fails
+     *
      */
     public synchronized void putData(long dataType, Object data) 
         throws CDFException {
@@ -722,6 +780,7 @@ synchronized(myAttribute) {
           this.xdataType = this.dataType;
           this.xnumElements = this.numElements;
           this.xdataSignature = this.dataSignature;
+          this.xdata = this.data;
           this.dataType = dataType;
           this.numElements = CDFUtils.getNumElements(dataType, data);
           this.dataSignature = CDFUtils.getSignature(data);
@@ -735,6 +794,7 @@ synchronized(myAttribute) {
 	} catch (CDFException ex) {
 	  this.dataType = this.xdataType;
 	  this.numElements = this.xnumElements;
+	  this.data = this.xdata;
 	  this.dataSignature = this.xdataSignature;
 	  throw new CDFException(ex.getCurrentStatus());
 	}
@@ -745,7 +805,7 @@ synchronized(myAttribute) {
      * select cmd vector since this is handled in the JNI native method
      * in cdfNativeLibrary.c.
      *
-     * @exception CDFException if there was a problem in selecting the
+     * @throws CDFException CDFException if there was a problem in selecting the
      *            current entry
      */
     protected synchronized final void select() throws CDFException {
