@@ -1,4 +1,4 @@
-// $Id: CDFUtils.java,v 1.2 2014/05/14 17:38:34 liu Exp $
+// $Id: CDFUtils.java,v 1.1.1.1 2017/01/04 20:58:09 liu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -30,7 +30,7 @@ public class CDFUtils implements CDFConstants {
      *
      * <B>NOTE</B>: Java primitive data types (e.g. int, long, byte, etc.) are
      *       not Objects.  Thus they must be passed-in as an Object by
-     *       using a wrapper (e.g. Integer(23)). <P>
+     *       using a wrapper (e.g. Integer(23)). 
      *  
      * <PRE> 
      *  Signature                 Java Programming Language Type
@@ -42,7 +42,7 @@ public class CDFUtils implements CDFConstants {
      *  [I                        array of int
      *  [J                        array of long
      *  [F                        array of float
-     *  [D                        array of double <P>
+     *  [D                        array of double 
      *
      *  L fully-qualified-class   fully-qualified class
      *  L fully-qualified-class;  array of fully-qualified class
@@ -252,7 +252,7 @@ public class CDFUtils implements CDFConstants {
      *  1-dimensional array of primitive Java data type. <P>
      *
      *  The following example will send the contents of the given data
-     *  to "myoutput.dat". <P>
+     *  to "myoutput.dat". 
      *  <PRE>
      *     OutputStreamWriter outWriter = null;
      *     PrintWriter out = null;
@@ -749,7 +749,7 @@ public class CDFUtils implements CDFConstants {
      *  Gets the string representation of the given CDF compression type. <P>
      *
      *  @param compressionType the CDF compression type to be translated.
-     *                         it should be one of the following: <P>
+     *                         it should be one of the following: 
      *          <UL>
      *             <LI>NO_COMPRESSION
      *             <LI>RLE_COMPRESSION
@@ -1239,6 +1239,18 @@ public class CDFUtils implements CDFConstants {
 
     }
 
+    /**
+     *  Gets the date of the given CDF's last updated for the leap second. <P>
+     *
+     *  @param cdf the CDF with which its leap second last updated.  
+     *  @return value (in YYYYMMDD) representation of leap second last updated,
+     *          if set. -1 if the value is not set (prior to CDF V3.5.1).
+     *  @throws CDFException An exception is thrown if the operation fails
+     */
+    public static long getLeapSecondLastUpdated (CDF cdf) throws CDFException {
+        return cdf.getLeapSecondLastUpdated();
+    }
+
     /**
      *  Gets the string value of the given CDF's checksum. <P>
      *
